==> qt-creator-2.4.1-src.zip: qt-creator-2.4.1-src/src/plugins/remotelinux/uploadandinstalltarpackagestep.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/
#ifndef UPLOADANDINSTALLTARPACKAGESTEP_H
#define UPLOADANDINSTALLTARPACKAGESTEP_H

#include "abstractuploadandinstallpackageservice.h"
#include "abstractremotelinuxdeploystep.h"

namespace RemoteLinux {
class AbstractRemoteLinuxPackageInstaller;

namespace Internal {
class UploadAndInstallTarPackageServicePrivate;
}

class REMOTELINUX_EXPORT UploadAndInstallTarPackageService : public AbstractUploadAndInstallPackageService
{
    Q_OBJECT

public:
    explicit UploadAndInstallTarPackageService(QObject *parent);
    ~UploadAndInstallTarPackageService();

private:
    AbstractRemoteLinuxPackageInstaller *packageInstaller() const;

    Internal::UploadAndInstallTarPackageServicePrivate *d;
};


class REMOTELINUX_EXPORT UploadAndInstallTarPackageStep : public AbstractRemoteLinuxDeployStep
{
    Q_OBJECT

public:
    explicit UploadAndInstallTarPackageStep(ProjectExplorer::BuildStepList *bsl);
    UploadAndInstallTarPackageStep(ProjectExplorer::BuildStepList *bsl,
        UploadAndInstallTarPackageStep *other);

    bool isDeploymentPossible(QString *whyNot = 0) const;

    static QString stepId();
    static QString displayName();

private:
    AbstractRemoteLinuxDeployService *deployService() const { return m_deployService; }

    void ctor();

    UploadAndInstallTarPackageService *m_deployService;
};

} //namespace RemoteLinux

#endif // UPLOADANDINSTALLTARPACKAGESTEP_H

==> qt-creator-2.5.2-src.zip: qt-creator-2.5.2-src/src/plugins/remotelinux/uploadandinstalltarpackagestep.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/
#ifndef UPLOADANDINSTALLTARPACKAGESTEP_H
#define UPLOADANDINSTALLTARPACKAGESTEP_H

#include "abstractuploadandinstallpackageservice.h"
#include "abstractremotelinuxdeploystep.h"

namespace RemoteLinux {
class AbstractRemoteLinuxPackageInstaller;

namespace Internal {
class UploadAndInstallTarPackageServicePrivate;
}

class REMOTELINUX_EXPORT UploadAndInstallTarPackageService : public AbstractUploadAndInstallPackageService
{
    Q_OBJECT

public:
    explicit UploadAndInstallTarPackageService(QObject *parent);
    ~UploadAndInstallTarPackageService();

private:
    AbstractRemoteLinuxPackageInstaller *packageInstaller() const;

    Internal::UploadAndInstallTarPackageServicePrivate *d;
};


class REMOTELINUX_EXPORT UploadAndInstallTarPackageStep : public AbstractRemoteLinuxDeployStep
{
    Q_OBJECT

public:
    explicit UploadAndInstallTarPackageStep(ProjectExplorer::BuildStepList *bsl);
    UploadAndInstallTarPackageStep(ProjectExplorer::BuildStepList *bsl,
        UploadAndInstallTarPackageStep *other);

    bool initInternal(QString *error = 0);

    ProjectExplorer::BuildStepConfigWidget *createConfigWidget();

    static QString stepId();
    static QString displayName();

private:
    AbstractRemoteLinuxDeployService *deployService() const { return m_deployService; }

    void ctor();

    UploadAndInstallTarPackageService *m_deployService;
};

} //namespace RemoteLinux

#endif // UPLOADANDINSTALLTARPACKAGESTEP_H
